package javax.swing.colorchooser;

import javax.swing.UIManager;
import java.awt.Component;

class ColorModel
{
    private final String prefix;
    private final String[] labels;
    
    ColorModel(String str, String... labels) {
        this.prefix = "ColorChooser." + str;
        this.labels = labels;
    }
    
    ColorModel() {
        this("rgb", new String[] { "Red", "Green", "Blue", "Alpha" });
    }
    
    void setColor(int n, float[] array) {
        array[0] = normalize(n >> 16);
        array[1] = normalize(n >> 8);
        array[2] = normalize(n);
        array[3] = normalize(n >> 24);
    }
    
    int getColor(float[] array) {
        return to8bit(array[2]) | to8bit(array[1]) << 8 | to8bit(array[0]) << 16 | to8bit(array[3]) << 24;
    }
    
    int getCount() {
        return this.labels.length;
    }
    
    int getMinimum(int n) {
        return 0;
    }
    
    int getMaximum(int n) {
        return 255;
    }
    
    float getDefault(int n) {
        return 0.0f;
    }
    
    final String getLabel(Component component, int n) {
        return this.getText(component, this.labels[n]);
    }
    
    private static float normalize(int n) {
        return (float)(n & 0xFF) / 255.0f;
    }
    
    private static int to8bit(float n) {
        return (int)(255.0f * n);
    }
    
    final String getText(Component component, String str) {
        return UIManager.getString(this.prefix + str + "Text", component.getLocale());
    }
    
    final int getInteger(Component component, String str) {
        Object value = UIManager.get(this.prefix + str, component.getLocale());
        if ((value instanceof Integer)) {
            return (int)value;
        }
        if ((value instanceof String)) {
            try {
                return Integer.parseInt((String)value);
            }
            catch (NumberFormatException ex) {}
        }
        return -1;
    }
}
